@@ -10,6 +10,47 @@
 #' 
 #' @param n Integer.
 #' Sample size (if the data provided is a correlation matrix)
+#' 
+#' @param uni.method Character.
+#' What unidimensionality method should be used? 
+#' Defaults to \code{"LE"}.
+#' Current options are:
+#' 
+#' \itemize{
+#'
+#' \item{\strong{\code{expand}}}
+#' {Expands the correlation matrix with four variables correlated .50.
+#' If number of dimension returns 2 or less in check, then the data 
+#' are unidimensional; otherwise, regular EGA with no matrix
+#' expansion is used. This is the method used in the Golino et al. (2020)
+#' \emph{Psychological Methods} simulation.}
+#'
+#' \item{\strong{\code{LE}}}
+#' {Applies the leading eigenvalue algorithm (\code{\link[igraph]{cluster_leading_eigen}})
+#' on the empirical correlation matrix. If the number of dimensions is 1,
+#' then the leading eigenvalue solution is used; otherwise, regular EGA
+#' is used. This is the final method used in the Christensen, Garrido,
+#' and Golino (2021) simulation.}
+#' 
+#' }
+#' 
+#' @param corr Type of correlation matrix to compute. The default uses \code{\link[qgraph]{cor_auto}}.
+#' Current options are:
+#'
+#' \itemize{
+#'
+#' \item{\strong{\code{cor_auto}}}
+#' {Computes the correlation matrix using the \code{\link[qgraph]{cor_auto}} function from
+#' \code{\link[qgraph]{qgraph}}}.
+#'
+#' \item{\strong{\code{pearson}}}
+#' {Computes Pearson's correlation coefficient using the pairwise complete observations via
+#' the \code{\link[stats]{cor}}} function.
+#'
+#' \item{\strong{\code{spearman}}}
+#' {Computes Spearman's correlation coefficient using the pairwise complete observations via
+#' the \code{\link[stats]{cor}}} function.
+#' }
 #'
 #' @param model Character.
 #' A string indicating the method to use.
@@ -74,20 +115,16 @@
 #' Golino, H., Moulder, R. G., Shi, D., Christensen, A. P., Garrido, L. E., Neito, M. D., Nesselroade, J., Sadana, R., Thiyagarajan, J. A., & Boker, S. M. (in press).
 #' Entropy fit indices: New fit measures for assessing the structure and dimensionality of multiple latent variables.
 #' \emph{Multivariate Behavioral Research}.
-#' \doi{10.31234/osf.io/mtka2}
 #' 
-#' # Original implementation of EGA.fit \cr
-#' Golino, H., Thiyagarajan, J. A., Sadana, M., Teles, M., Christensen, A. P., & Boker, S. M. (under review).
-#' Investigating the broad domains of intrinsic capacity, functional ability, and environment:
-#' An exploratory graph analysis approach for improving analytical methodologies for measuring healthy aging.
+#' # Simulation for EGA.fit \cr
+#' Jamison, L., Christensen, A. P., & Golino, H. (under review).
+#' Optimizing Walktrap's community detection in networks using the Total Entropy Fit Index.
 #' \emph{PsyArXiv}.
-#' \doi{10.31234/osf.io/hj5mc}
 #' 
 #' # Walktrap algorithm \cr
 #' Pons, P., & Latapy, M. (2006).
 #' Computing communities in large networks using random walks.
 #' \emph{Journal of Graph Algorithms and Applications}, \emph{10}, 191-218.
-#' \doi{10.7155/jgaa.00185}
 #'
 #' @seealso \code{\link[EGAnet]{bootEGA}} to investigate the stability of EGA's estimation via bootstrap,
 #' \code{\link[EGAnet]{EGA}} to estimate the number of dimensions of an instrument using EGA,
@@ -97,13 +134,45 @@
 #'
 #' @export
 # EGA fit
-# Updated 11.11.2020
-EGA.fit <- function (data, model = c("glasso","TMFG"),
-                     steps = c(3,4,5,6,7,8), n = NULL)
+# Updated 08.03.2021
+EGA.fit <- function (data, n = NULL, uni.method = c("expand", "LE"),
+                     corr = c("cor_auto", "pearson", "spearman"),
+                     model = c("glasso","TMFG"),
+                     steps = c(3,4,5,6,7,8))
 {
+  if(missing(uni.method)){
+    uni.method <- "LE"
+  }else{uni.method <- match.arg(uni.method)}
+  
+  # Check if uni.method = "LE" has been used
+  if(uni.method == "LE"){
+    # Give change warning
+    warning(
+      paste(
+        "Previous versions of EGAnet (<= 0.9.8) checked unidimensionality using",
+        styletext('uni.method = "expand"', defaults = "underline"),
+        "as the default"
+      )
+    )
+  }else if(uni.method == "expand"){
+    # Give change warning
+    warning(
+      paste(
+        "Newer evidence suggests that",
+        styletext('uni.method = "LE"', defaults = "underline"),
+        'is more accurate than uni.method = "expand" (see Christensen, Garrido, & Golino, 2021 in references).',
+        '\n\nIt\'s recommended to use uni.method = "LE"'
+      )
+    )
+  }
+  
   if(missing(model))
   {model <- "glasso"
   }else{model <- match.arg(model)}
+  
+  if(missing(corr))
+  {corr <- "cor_auto"
+  }else{corr <- match.arg(corr)}
 
   if(missing(steps))
   {steps <- c(3,4,5,6,7,8)
@@ -112,7 +181,11 @@ EGA.fit <- function (data, model = c("glasso","TMFG"),
   #Speed up process with data
   if(nrow(data) != ncol(data)){
     n <- nrow(data)
-    data <- qgraph::cor_auto(data)
+    data <- switch(corr,
+                   "cor_auto" = qgraph::cor_auto(data),
+                   "pearson" = cor(data, use = "pairwise.complete.obs"),
+                   "spearman" = cor(data, method = "spearman", use = "pairwise.complete.obs")
+    )
   }
 
   best.fit <- list()
